<?php
/**
 * Register the settings for the theme. This is required for using the
 * Wordpress Settings API.
*/
function antiaris_settings_init(){
	// register options set and store it in antiaris_settings db entry
	register_setting('antiaris_options', 'antiaris_settings', 'antiaris_settings_validator');
}
add_action('admin_init', 'antiaris_settings_init');

/* Include the settings validator */
include('validator.php');


/**
 * This is the function that will manage the dsplay of the theme's
 * options page in the admin panel
*/
function antiaris_options(){
	
	global $antiaris_settings, $antiaris_defaults;
	$antiaris_settings = get_option('antiaris_settings');
	
	// printf('settings: %d, defaults: %d', count($antiaris_settings), count($antiaris_defaults));
	
	/*
	echo "<pre>";
	print_r($antiaris_settings);
	echo "</pre>";
	*/
	
	/* Checks if the form has just been submitted */
	if (!isset($_REQUEST['updated'])) {$_REQUEST['updated'] = false;} 
	
	
	/* Apply options preset if submitted */ 
	if (isset($_POST['antiaris_preset'])) {
		include('options-presets.php');
	}
	
	/* Uninstall the theme if confirmed */
	if (isset($_POST['antiaris_uninstall_confirmed'])) { 
		include('uninstall.php');
	}
	
	/* Display a confirmation page to uninstall the theme */
	if (isset($_POST['antiaris_uninstall'])) { 
	?>

		<div class="wrap">
        <h2><?php _e('Uninstall Antiaris', 'antiaris'); ?></h2>
        <p><?php _e("Please confirm that you would like to uninstall the Antiaris theme. All of the theme's options in the database will be deleted.", 'antiaris'); ?></p>
        <p><?php _e('This action is not reversible.', 'antiaris'); ?></p>
        <form action="" method="post">
        	<?php wp_nonce_field('antiaris-uninstall', 'antiaris-uninstall'); ?>
        	<input type="hidden" name="antiaris_uninstall_confirmed" value="true" />
            <input type="submit" class="button antiaris_uninstall" value="<?php _e('Uninstall Theme', 'antiaris'); ?>" />
        </form>
        </div>
        
		<?php
		return;
	}	
	
	/* This where we start outputting the options page */ ?>
    <div class="wrap meta-box-sortables">
    	<h2><?php _e('Antiaris Options', 'antiaris'); ?></h2>
        <p><?php _e("This page contains the settings that you can set for the theme. To use the theme's default values for any settings, just leave the setting's field empty.", "antiaris"); ?></p>
        
        <?php /* Notification when settings is saved */ ?>
        <?php if ( false !== $_REQUEST['updated'] ) : ?>
        	<div class="updated"><p><strong><?php _e('Settings saved.', 'antiaris'); ?></strong></p></div>
        <?php endif; ?>
        
        <div class="left-wrap">
        
        <?php /* Options Presets. This uses separate form than the main form */ ?>
        <div class="postbox preset">
            <div class="head-wrap">
                <div title="Click to toggle" class="handlediv"><br /></div>
                <h3 class="hndle"><?php _e('Options Presets', 'antiaris'); ?></h3>
            </div>
            <div class="panel-wrap inside">
                <p><?php _e("The default settings for the theme is preconfigured for use in blogs. If you're using this theme primarily for a normal website, or if you want to reset the settings to their default values, you can apply one of the available options presets below.", 'antiaris'); ?></p>
                <p><?php _e("Note that you can still configure the individual settings after you apply any preset.", 'antiaris'); ?></p>
                <form action="" method="post">
                    <?php wp_nonce_field('antiaris-preset', 'antiaris-preset'); ?>
                	<table class="form-table">
                        <tr>
                            <th scope="row"><?php _e('Select Options Preset', 'antiaris'); ?></th>
                            <td class="options-cat-list">
                                <input type="radio" name="antiaris_options_preset" value="website" id="antiaris_options_preset-website" />
                                <label for="antiaris_options_preset-website"><?php _e('Normal website', 'antiaris'); ?></label>
                                
                                <input type="radio" name="antiaris_options_preset" value="reset" id="antiaris_options_preset-reset" />
                                <label for="antiaris_options_preset-reset"><?php _e('Reset to default settings', 'antiaris'); ?></label>
                            </td>
                        </tr>
                    </table>
                    <input type="hidden" name="antiaris_preset" value="true" />
                    <input type="submit" class="button antiaris_preset" value="<?php _e('Apply Options Preset', 'antiaris'); ?>" />
                </form>
            </div>
        </div>
        
        
        
        <?php /* Begin the main form */ ?>
        <form method="post" action="options.php" class="mainform clearfix">
		
		<?php /* Output wordpress hidden form fields, e.g. nonce etc. */ ?>
		<?php settings_fields('antiaris_options'); ?>
        
		
        <?php /* Site Summary Panel options */ ?>
        <div class="postbox">
            <div class="head-wrap">
            	<div title="Click to toggle" class="handlediv"><br /></div>
            	<h3 class="hndle"><?php _e('Site Summary Panel', 'antiaris'); ?></h3>
            </div>
            <div class="panel-wrap inside">
                <table class="form-table site-summary">
                    <tr>
                        <th scope="row"><?php _e('Latest post category', 'antiaris'); ?></th>
                        <td class="options-cat-list">
                            <span class="description"><?php _e('The latest post from each of the category selected here will be displayed on the left side of the Site Summary panel. Defaults to Uncategorized if no category is selected.', 'antiaris'); ?></span><br />
                            
                            <?php /* Get the current settings */ 
                            $latestpost_cats = (!is_array($antiaris_settings['latestpost_cats']) || empty($antiaris_settings['latestpost_cats'])) ? $antiaris_defaults['latestpost_cats'] : $antiaris_settings['latestpost_cats'];
                            
                            /* Get the list of categories and display as checkboxes */ 
                            $cats = get_categories();
                            foreach ($cats as $cat) : $cat_id = $cat->cat_ID;
                            ?>
                            <span class="input-wrap">
                            <input type="checkbox" name="antiaris_settings[latestpost_cats][]" id="latestpost_cats-<?php echo $cat_id; ?>" value="<?php echo $cat_id; ?>" <?php if (in_array($cat_id, $latestpost_cats)) {echo 'checked="checked" ';} ?>/>
                            <label for="latestpost_cats-<?php echo $cat_id; ?>"><?php echo $cat->cat_name; ?></label>
                            </span>
                            <?php endforeach; ?>
                            
                        </td>
                    </tr>
                    
                    <tr>
                        <th scope="row"><label><?php _e('Number of latest posts to display', 'antiaris'); ?></label></th>
                        <td>
                            <input type="text" name="antiaris_settings[latestpost_count]" id="latestpost_count" maxlength="2" size="1" value="<?php echo $antiaris_settings['latestpost_count']; ?>" />
                        </td>
                    </tr>
                    
                    <tr>
                        <th scope="row"><label><?php _e('Number of popular posts to display', 'antiaris'); ?></label></th>
                        <td>
                            <input type="text" name="antiaris_settings[popularpost_count]" id="popularpost_count" maxlength="2" size="1" value="<?php echo $antiaris_settings['popularpost_count']; ?>" />
                        </td>
                    </tr>
                    
                    <tr>
                        <th scope="row"><label><?php _e('Number of latest comments to display', 'antiaris'); ?></label></th>
                        <td>
                            <input type="text" name="antiaris_settings[latestcomment_count]" id="latestcomment_count" maxlength="2" size="1" value="<?php echo $antiaris_settings['latestcomment_count']; ?>" />
                        </td>
                    </tr>
                    
                    <tr>
                        <th scope="row"><label><?php _e('Number of tags to display', 'antiaris'); ?></label></th>
                        <td>
                            <input type="text" name="antiaris_settings[tags_count]" id="tags_count" maxlength="2" size="1" value="<?php echo $antiaris_settings['tags_count']; ?>" />
                        </td>
                    </tr>
                    <tr>
                        <th scope="row"><label><?php _e('Site Summary Panel height', 'antiaris'); ?></label></th>
                        <td>
                            <input type="text" name="antiaris_settings[summarypanel_height]" id="summarypanel_height" maxlength="4" size="3" value="<?php echo $antiaris_settings['summarypanel_height']; ?>" />&nbsp;<?php _e('pixels', 'antiaris'); ?>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row"><label><?php _e('Left side tabs duration', 'antiaris'); ?></label></th>
                        <td>
                            <input type="text" name="antiaris_settings[summarypanel_left_duration]" id="summarypanel_left_duration" maxlength="5" size="5" value="<?php echo $antiaris_settings['summarypanel_left_duration']; ?>" />&nbsp;<?php _e('miliseconds', 'antiaris'); ?>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row"><label><?php _e('Right side tabs duration', 'antiaris'); ?></label></th>
                        <td>
                            <input type="text" name="antiaris_settings[summarypanel_right_duration]" id="summarypanel_right_duration" maxlength="5" size="5" value="<?php echo $antiaris_settings['summarypanel_right_duration']; ?>" />&nbsp;<?php _e('miliseconds', 'antiaris'); ?>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                        	<label for="left_tab_shows"><?php _e('Left side shows', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="radio" value="categories-latest-post" name="antiaris_settings[left_tab_shows]" id="left_tab_shows-latest-post" <?php if ($antiaris_settings['left_tab_shows'] == 'categories-latest-post') {echo 'checked="checked"';} ?> />
                            <label for="left_tab_shows-latest-post"><?php _e('Categories latest post', 'antiaris'); ?></label>
                            
                            <input type="radio" value="posts-slider" name="antiaris_settings[left_tab_shows]" id="left_tab_shows-slider" <?php if ($antiaris_settings['left_tab_shows'] == 'posts-slider') {echo 'checked="checked"';} ?> />
                            <label for="left_tab_shows-slider"><?php _e('Posts slider', 'antiaris'); ?></label>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                        	<label for="disable_summarypanel"><?php _e('Show full-sized slider instead of the site summary', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="checkbox" value="true" name="antiaris_settings[show_slider]" id="show_slider" <?php if ($antiaris_settings['show_slider']) {echo 'checked="checked"';} ?> />
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                        	<label for="disable_summarypanel"><?php _e('Disable Site Summary Panel', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="checkbox" value="true" name="antiaris_settings[disable_summarypanel]" id="disable_summarypanel" <?php if ($antiaris_settings['disable_summarypanel'] == true) {echo 'checked="checked"';} ?> />
                        </td>
                    </tr>
                </table>
            </div>
        </div>
        
        
        <?php /* Slider options */ ?>
        <div class="postbox">
            <div class="head-wrap">
            	<div title="Click to toggle" class="handlediv"><br /></div>
            	<h3 class="hndle"><?php _e('Posts Slider', 'antiaris'); ?></h3>
            </div>
            <div class="panel-wrap inside">
            	<p><?php _e('The settings in this section only apply if you select <strong>Posts slider</strong> for the <strong>Left side shows</strong> option in the Site Summary Panel options above, or the <strong>Show full-sized slider instead of the site summary</strong> option is enabled.', 'antiaris'); ?></p>
                <table class="form-table site-summary">
                	<tr>
                        <th scope="row">
                            <label><?php _e('Category to show in slider', 'antiaris'); ?></label><br />
                            <small><?php _e('All posts within the category selected here will be displayed on the slider. Usage example: create a new category called "Featured" and assign all posts to be displayed on the slider to that category, and then select that category here.', 'antiaris'); ?></small>
                        </th>
                        <td>
                            <select name="antiaris_settings[slider_cat]">
                                <option value=""><?php _e('Show latest posts', 'antiaris'); ?></option>
                                <option value="" disabled="disabled">--------------------</option>
                                <?php /* Get the list of categories */ 
                                    $categories = get_categories();
                                    foreach ($categories as $category) :
                                ?>
                                <option value="<?php echo $category->cat_ID; ?>" <?php if ($antiaris_settings['slider_cat'] == $category->cat_ID) {echo 'selected="selected"';}?>><?php echo $category->cat_name; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                            <label><?php _e('Number of latest posts to display', 'antiaris'); ?></label>
                        </th>
                        <td>
                            <input type="text" name="antiaris_settings[slider_postcount]" value="<?php echo $antiaris_settings['slider_postcount']; ?>" size="3" /><br />
                            <span class="description"><?php _e('This setting only affects the slider if "Show latest posts" is selected above.', 'antiaris'); ?></span>                        
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                            <label><?php _e('Slider height', 'antiaris'); ?></label>
                        </th>
                        <td>
                            <input type="text" name="antiaris_settings[slider_height]" value="<?php echo $antiaris_settings['slider_height']; ?>" size="3" /> <?php _e('pixels', 'antiaris'); ?><br />
                            <span class="description"><?php _e('This is the height of the slider if displayed on the left side of the Site Summary Panel', 'antiaris'); ?></span>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                            <label><?php _e('Slider speed', 'antiaris'); ?></label>
                        </th>
                        <td>
                            <input type="text" name="antiaris_settings[slider_speed]" value="<?php echo $antiaris_settings['slider_speed']; ?>" size="3" /> <?php _e('miliseconds', 'antiaris'); ?>
                        </td>
                    </tr>
                </table>
            </div>
        </div>
        
        
        <?php /* Homepage panes options */ ?>
        <div class="postbox">
            <div class="head-wrap">
            	<div title="Click to toggle" class="handlediv"><br /></div>
            	<h3 class="hndle"><?php _e('Homepage Panes', 'antiaris'); ?></h3>
            </div>
            <div class="panel-wrap inside">
            	<p><?php _e('<strong>Note:</strong> homepage panes are only displayed when using a <a href="http://codex.wordpress.org/Creating_a_Static_Front_Page">static front page</a>.', 'antiaris'); ?></p>
                <table class="form-table site-summary">
                	<tr>
                    	<th scope="row">
                        	<?php _e('Type of content to show', 'antiaris'); ?>
                        </th>
                        <td>
                            <input type="radio" name="antiaris_settings[show_post_type]" value="latest-posts" id="show_post_type-latest-posts" <?php if ($antiaris_settings['show_post_type'] == 'latest-posts') {echo 'checked="checked"';} ?>/>
                            <label for="show_post_type-latest-posts"><?php _e('Latest posts', 'antiaris'); ?></label>
                            
                            <input type="radio" name="antiaris_settings[show_post_type]" value="cat-latest-posts" id="show_post_type-cat-latest-posts" <?php if ($antiaris_settings['show_post_type'] == 'cat-latest-posts') {echo 'checked="checked"';} ?>/>
                            <label for="show_post_type-cat-latest-posts"><?php _e('Latest posts by category', 'antiaris'); ?></label>
                           
                            <input type="radio" name="antiaris_settings[show_post_type]" value="posts" id="show_post_type-pages" <?php if ($antiaris_settings['show_post_type'] == 'posts') {echo 'checked="checked"';} ?>/>
                            <label for="show_post_type-pages"><?php _e('Posts and/or pages', 'antiaris'); ?></label>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                            <label><?php _e('Number of latest posts to display', 'antiaris'); ?></label>
                        </th>
                        <td>
                            <input type="text" name="antiaris_settings[homepage_panes_count]" value="<?php echo $antiaris_settings['homepage_panes_count']; ?>" size="1" /><br />
                            <span class="description"><?php _e('Applicable only if <strong>Latest posts</strong> or <strong>Latest posts by category</strong> is selected above.', 'antiaris'); ?></span>                        
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                            <label><?php _e('Category to show latest posts from', 'antiaris'); ?></label>
                        </th>
                        <td>
                            <select name="antiaris_settings[homepage_panes_cat]">
                                <?php /* Get the list of categories */ 
                                    foreach ($categories as $category) :
                                ?>
                                <option value="<?php echo $category->cat_ID; ?>" <?php if ($antiaris_settings['homepage_panes_cat'] == $category->cat_ID) {echo 'selected="selected"';}?>><?php echo $category->cat_name; ?></option>
                                <?php endforeach; ?>
                            </select><br />
                            <span class="description"><?php _e('Applicable only if <strong>Latest posts by category</strong> is selected above.', 'antiaris'); ?></span>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                            <label><?php _e('Posts and/or pages to display', 'antiaris'); ?></label>
                        </th>
                        <td>
                            <input type="text" name="antiaris_settings[homepage_panes_posts]" value="<?php echo $antiaris_settings['homepage_panes_posts']; ?>" size="10" class="code" /><br />
                            <span class="description">
							<?php _e('Enter ID of posts and/or pages to be displayed, separated by comma. Example: <code>1,13,45,33</code>', 'antiaris'); ?><br />
							<?php _e('Applicable only if <strong>Posts and/or pages</strong> is selected above.', 'antiaris'); ?>
                            </span>                        
                        </td>
                    </tr>
                	<tr>
                        <th scope="row">
                        	<label for="disable_homepage_panes"><?php _e('Disable homepage panes', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="checkbox" value="true" name="antiaris_settings[disable_homepage_panes]" id="disable_homepage_panes" <?php if ($antiaris_settings['disable_homepage_panes']) {echo 'checked="checked"';} ?> />
                        </td>
                    </tr>
                </table>
            </div>
        </div>
        
        
        <?php /* Widget areas options */ ?>
        <div class="postbox">
            <div class="head-wrap">
            	<div title="Click to toggle" class="handlediv"><br /></div>
            	<h3 class="hndle"><?php _e('Sidebars and Widget Areas', 'antiaris'); ?></h3>
            </div>
            <div class="panel-wrap inside">
            	<h4><?php _e('Sidebars widget area', 'antiaris'); ?></h4>
                <table class="form-table site-summary">
                	<tr>
                        <th scope="row">
                        	<label for="disable_left_sidebar"><?php _e('Disable left sidebar', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="checkbox" value="true" name="antiaris_settings[disable_left_sidebar]" id="disable_left_sidebar" <?php if ($antiaris_settings['disable_left_sidebar']) {echo 'checked="checked"';} ?> />
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                        	<label for="disable_right_sidebar"><?php _e('Disable right sidebar', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="checkbox" value="true" name="antiaris_settings[disable_right_sidebar]" id="disable_right_sidebar" <?php if ($antiaris_settings['disable_right_sidebar']) {echo 'checked="checked"';} ?> />
                        </td>
                    </tr>
                </table>
                
                
                <h4><?php _e('Header widget area', 'antiaris'); ?></h4>
                <p><?php _e('<strong>Important:</strong> This widget area is unstyled, as it is often used for advertisement banners, etc. If you enable it, make sure you style it using the Custom CSS option.', 'antiaris'); ?></p>
                <table class="form-table site-summary">
                    <tr>
                        <th scope="row">
                        	<label for="enable_header_widget"><?php _e('Enable header widget area', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="checkbox" value="true" name="antiaris_settings[enable_header_widget]" id="enable_header_widget" <?php if ($antiaris_settings['enable_header_widget']) {echo 'checked="checked"';} ?> />
                        </td>
                    </tr>
                </table>
                
                
            	<h4><?php _e('Footer widget area', 'antiaris'); ?></h4>
                <table class="form-table site-summary">
                    <tr>
                        <th scope="row">
                        	<label><?php _e('Number of widget columns to use', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="text" name="antiaris_settings[footer_widget_count]" id="footer_widget_count" maxlength="2" size="1" value="<?php echo $antiaris_settings['footer_widget_count']; ?>" />
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                        	<label for="disable_footer_widget"><?php _e('Disable footer widget area', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="checkbox" value="true" name="antiaris_settings[disable_footer_widget]" id="disable_footer_widget" <?php if ($antiaris_settings['disable_footer_widget']) {echo 'checked="checked"';} ?> />
                        </td>
                    </tr>
                </table>
                
                <h4><?php _e('Alternate front page widget areas', 'antiaris'); ?></h4>
                <p><?php _e('If you like, you can have a different set of sidebars and widget areas that are displayed only on the front page.', 'antiaris'); ?></p>
                <table class="form-table site-summary">
                    <tr>
                        <th scope="row">
                        	<label for="enable_alternate_left_sidebar"><?php _e('Enable alternate left sidebar', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="checkbox" value="true" name="antiaris_settings[enable_alternate_left_sidebar]" id="enable_alternate_left_sidebar" <?php if ($antiaris_settings['enable_alternate_left_sidebar']) {echo 'checked="checked"';} ?> />
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                        	<label for="enable_alternate_right_sidebar"><?php _e('Enable alternate right sidebar', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="checkbox" value="true" name="antiaris_settings[enable_alternate_right_sidebar]" id="enable_alternate_right_sidebar" <?php if ($antiaris_settings['enable_alternate_right_sidebar']) {echo 'checked="checked"';} ?> />
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                        	<label for="enable_alternate_footer_widget"><?php _e('Enable alternate footer widget area', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="checkbox" value="true" name="antiaris_settings[enable_alternate_footer_widget]" id="enable_alternate_footer_widget" <?php if ($antiaris_settings['enable_alternate_footer_widget']) {echo 'checked="checked"';} ?> />
                        </td>
                    </tr>
                </table>
            </div>
        </div>
        
        
        <?php /* Posts and Pages Display options */ ?>
        <div class="postbox">
            <div class="head-wrap">
            	<div title="Click to toggle" class="handlediv"><br /></div>
            	<h3 class="hndle"><?php _e('Posts and Pages Display', 'antiaris'); ?></h3>
            </div>
            <div class="panel-wrap inside">.
            	<h4><?php _e('Post display settings', 'antiaris'); ?></h4>
                <table class="form-table site-summary">
                    <tr>
                        <th scope="row">
                        	<label for="excerpt_in_frontpage"><?php _e('Show excerpt in front page', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="checkbox" value="true" name="antiaris_settings[excerpt_in_frontpage]" id="excerpt_in_frontpage" <?php if ($antiaris_settings['excerpt_in_frontpage']) {echo 'checked="checked"';} ?> />
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                        	<label for="hide_post_author"><?php _e('Hide post author', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="checkbox" value="true" name="antiaris_settings[hide_post_author]" id="hide_post_author" <?php if ($antiaris_settings['hide_post_author']) {echo 'checked="checked"';} ?> />
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                        	<label for="hide_post_date"><?php _e('Hide post date', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="checkbox" value="true" name="antiaris_settings[hide_post_date]" id="hide_post_date" <?php if ($antiaris_settings['hide_post_date']) {echo 'checked="checked"';} ?> />
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                        	<label for="hide_post_categories"><?php _e('Hide post categories', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="checkbox" value="true" name="antiaris_settings[hide_post_categories]" id="hide_post_categories" <?php if ($antiaris_settings['hide_post_categories']) {echo 'checked="checked"';} ?> />
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                        	<label for="hide_post_tags"><?php _e('Hide post tags', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="checkbox" value="true" name="antiaris_settings[hide_post_tags]" id="hide_post_tags" <?php if ($antiaris_settings['hide_post_tags']) {echo 'checked="checked"';} ?> />
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                        	<label for="hide_post_commentcount"><?php _e('Hide post comment count', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="checkbox" value="true" name="antiaris_settings[hide_post_commentcount]" id="hide_post_commentcount" <?php if ($antiaris_settings['hide_post_commentcount']) {echo 'checked="checked"';} ?> />
                            <span class="description"><?php _e('This setting only affects posts listing (such as the front page) and not single post view.', 'antiaris'); ?></span>
                        </td>
                    </tr>
                </table>
                
                <h4><?php _e('Page display settings', 'antiaris'); ?></h4>
                <p><?php _e('By default, the post meta and post footer section are not displayed for Pages. You can enable them here if you like to.', 'antiaris'); ?></p>
                <table class="form-table site-summary">
                    <tr>
                        <th scope="row">
                        	<label for="enable_page_meta"><?php _e('Enable Post Meta in Pages', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="checkbox" value="true" name="antiaris_settings[enable_page_meta]" id="enable_page_meta" <?php if ($antiaris_settings['enable_page_meta']) {echo 'checked="checked"';} ?> />
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                        	<label for="enable_page_footer"><?php _e('Enable Post Footer in Pages', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="checkbox" value="true" name="antiaris_settings[enable_page_footer]" id="enable_page_footer" <?php if ($antiaris_settings['enable_page_footer']) {echo 'checked="checked"';} ?> />
                        </td>
                    </tr>
                </table>
            </div>
        </div>
        
        
        <?php /* Comments options */ ?>
        <div class="postbox">
            <div class="head-wrap">
            	<div title="Click to toggle" class="handlediv"><br /></div>
            	<h3 class="hndle"><?php _e('Comments', 'antiaris'); ?></h3>
            </div>
            <div class="panel-wrap inside">
                <table class="form-table site-summary">
                    <tr>
                        <th scope="row" style="width:350px;">
                        	<label for="hide_comments_allowed_tags"><?php _e('Hide the "Allowed tags" note in comment form', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="checkbox" value="true" name="antiaris_settings[hide_comments_allowed_tags]" id="hide_comments_allowed_tags" <?php if ($antiaris_settings['hide_comments_allowed_tags']) {echo 'checked="checked"';} ?> />
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                        	<label for="disable_comments"><?php _e('Remove the comment section altogether', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="checkbox" value="true" name="antiaris_settings[disable_comments]" id="disable_comments" <?php if ($antiaris_settings['disable_comments']) {echo 'checked="checked"';} ?> />
                        </td>
                    </tr>
                </table>
            </div>
        </div>
        
        
        <?php /* Footer options */ ?>
        <div class="postbox">
            <div class="head-wrap">
            	<div title="Click to toggle" class="handlediv"><br /></div>
            	<h3 class="hndle"><?php _e('Footer Area', 'antiaris'); ?></h3>
            </div>
            <div class="panel-wrap inside">
                <table class="form-table site-summary">
                    <tr>
                        <th scope="row">
                        	<label><?php _e('Copyright text (html allowed)', 'antiaris'); ?></label>
                             <p><small><?php _e('If this field is empty, the following default copyright text will be displayed:', 'antiaris'); ?></small></p>
                             <p style="background-color:#fff;padding:5px;border:1px solid #ddd;">
                                 <small>
                                 	<?php echo $antiaris_defaults['copyright_text']; ?>
                                 </small>
                             </p>
                             </th>
                        <td>
                        	<textarea name="antiaris_settings[copyright_text]" cols="60" rows="7" class="widefat code"><?php echo stripslashes($antiaris_settings['copyright_text']); ?></textarea>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                        	<label for="disable_copyright"><?php _e('Disable copyright text', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="checkbox" value="true" name="antiaris_settings[disable_copyright]" id="disable_copyright" <?php if ($antiaris_settings['disable_copyright']) {echo 'checked="checked"';} ?> />
                        </td>
                    </tr>
                </table>
            </div>
        </div>
        
        
        <?php /* Syndication options */ ?>
        <div class="postbox">
            <div class="head-wrap">
            	<div title="Click to toggle" class="handlediv"><br /></div>
            	<h3 class="hndle"><?php _e('Syndication', 'antiaris'); ?></h3>
            </div>
            <div class="panel-wrap inside">
                <table class="form-table">
                    <tr>
                        <th scope="row"><label><?php _e('Custom feed URL', 'antiaris'); ?></label></th>
                        <td>
                        	<input name="antiaris_settings[feed_url]" class="code widefat" value="<?php echo stripslashes($antiaris_settings['feed_url']); ?>" />
                        	<span class="description"><?php _e("If present, this custom feed URL will replace the default Wordpress RSS feed URL.", 'antiaris'); ?></span>
                        </td>
                    </tr>
                </table>
            </div>
        </div>
        
        
        <?php /* Social Sharing buttons */ ?>
        <div class="postbox">
            <div class="head-wrap">
            	<div title="Click to toggle" class="handlediv"><br /></div>
            	<h3 class="hndle"><?php _e('Social Sharing', 'antiaris'); ?></h3>
            </div>
            <div class="panel-wrap inside">
                <table class="form-table">
                	<tr>
                        <th scope="row" style="width:250px;">
                        	<label for="enable_social_sharing"><?php _e('Enable social sharing buttons', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="checkbox" value="true" name="antiaris_settings[enable_social_sharing]" id="enable_social_sharing" <?php if ($antiaris_settings['enable_social_sharing']) {echo 'checked="checked"';} ?> />
                        </td>
                    </tr>
                    <tr>
                        <th scope="row"><label><?php _e('Social sharing buttons code', 'antiaris'); ?></label>
                        <p><small><?php _e("You can use codes from any social sharing services, like Facebook, AddThis, Twitter, etc.", 'antiaris'); ?></small></p>
                        </th>
                        <td>
                        	<textarea name="antiaris_settings[social_sharing_code]" cols="60" rows="10" class="widefat code"><?php echo stripslashes($antiaris_settings['social_sharing_code']); ?></textarea>
                        </td>
                    </tr>
                </table>
            </div>
        </div>
        
        
        <?php /* Google Adsense */ ?>
        <div class="postbox">
            <div class="head-wrap">
            	<div title="Click to toggle" class="handlediv"><br /></div>
            	<h3 class="hndle"><?php _e('Google Adsense', 'antiaris'); ?></h3>
            </div>
            <div class="panel-wrap inside">
                <table class="form-table">
                	<tr>
                        <th scope="row" style="width:250px;">
                        	<label for="enable_adsense"><?php _e('Enable Google Adsense ads display', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="checkbox" value="true" name="antiaris_settings[enable_adsense]" id="enable_adsense" <?php if ($antiaris_settings['enable_adsense']) {echo 'checked="checked"';} ?> />
                        </td>
                    </tr>
                    <tr>
                        <th scope="row"><label><?php _e('Google Adsense ad code', 'antiaris'); ?></label>
                        <p><small><?php _e("The ads will be placed under the post, so it's best to use a horizontal-format ad.", 'antiaris'); ?></small></p>
                        </th>
                        <td>
                        	<textarea name="antiaris_settings[adsense_code]" cols="60" rows="10" class="widefat code"><?php echo stripslashes($antiaris_settings['adsense_code']); ?></textarea>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row" style="width:250px;">
                        	<label for="enable_adsense_premium"><?php _e("I'm an Adsense Premium Publisher", 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="checkbox" value="true" name="antiaris_settings[enable_adsense_premium]" id="enable_adsense_premium" <?php if ($antiaris_settings['enable_adsense_premium']) {echo 'checked="checked"';} ?> /><br />
                            <span class="description"><?php _e('If you are an Adsense Premium Publisher, enabling this will remove the maximum 3 ads content per page limitation.', 'antiaris'); ?></span>
                        </td>
                    </tr>
                </table>
            </div>
        </div>
        
        
        <?php /* Google Analytics */ ?>
        <div class="postbox">
            <div class="head-wrap">
            	<div title="Click to toggle" class="handlediv"><br /></div>
            	<h3 class="hndle"><?php _e('Google Analytics', 'antiaris'); ?></h3>
            </div>
            <div class="panel-wrap inside">
            	<p><?php _e('The Google Analytics code you entered below will be placed in the <code>&lt;head&gt;</code> element in accordance with the new asynchronous Google Analytics script. If you have been using the older, non-asynchronous script, please get the new script from your Google Analytics account.', 'antiaris'); ?></p>
                <table class="form-table">
                	<tr>
                        <th scope="row" style="width:250px;">
                        	<label for="enable_analytics"><?php _e('Enable Google Analytics tracking', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="checkbox" value="true" name="antiaris_settings[enable_analytics]" id="enable_analytics" <?php if ($antiaris_settings['enable_analytics']) {echo 'checked="checked"';} ?> />
                        </td>
                    </tr>
                    <tr>
                        <th scope="row"><label><?php _e('Google Analytics tracking code', 'antiaris'); ?></label>
                        <p><small><?php _e('Make sure you include the full tracking code (including the <code>&lt;script&gt;</code> and <code>&lt;/script&gt;</code> tags) and not just the <code>UA-#######-#</code> code.', 'antiaris'); ?></small></p>
                        </th>
                        <td>
                        	<textarea name="antiaris_settings[analytics_code]" cols="60" rows="10" class="widefat code"><?php echo stripslashes($antiaris_settings['analytics_code']); ?></textarea>
                        </td>
                    </tr>
                </table>
            </div>
        </div>
        
        
        <?php /* Miscellaneous */ ?>
        <div class="postbox">
            <div class="head-wrap">
            	<div title="Click to toggle" class="handlediv"><br /></div>
            	<h3 class="hndle"><?php _e('Other Display Options', 'antiaris'); ?></h3>
            </div>
            <div class="panel-wrap inside">
            	<h4><?php _e('Site title options'); ?></h4>
                <p><?php _e('Use these tags to customise your own site title structure: <code>#site-name</code>, <code>#site-desc</code>, <code>#post-title</code>', 'antiaris'); ?></p>
                <table class="form-table">
                	<tr>
                        <th scope="row" style="width:250px;">
                        	<label><?php _e("Custom front page site title", 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="text" name="antiaris_settings[custom_site_title_frontpage]" id="custom_site_title_frontpage" class="widefat code" value="<?php echo stripslashes($antiaris_settings['custom_site_title_frontpage']); ?>" />
                            <span class="description"><?php _e('Defaults to <code>#site-name &raquo; #site-desc</code>. The <code>#post-title</code> tag cannot be used here.', 'antiaris'); ?></span>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row" style="width:250px;">
                        	<label><?php _e("Custom content pages site title", 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="text" name="antiaris_settings[custom_site_title_content]" id="custom_site_title_content" class="widefat code" value="<?php echo stripslashes($antiaris_settings['custom_site_title_content']); ?>" />
                            <span class="description"><?php _e('Defaults to <code>#post-title &raquo; #site-name</code>.', 'antiaris'); ?></span>
                        </td>
                    </tr>
                </table>
                
                <h4><?php _e('Menu options'); ?></h4>
                <table class="form-table">
                    <tr>
                        <th scope="row" style="width:250px;">
                        	<label for="disable_secondary_menu"><?php _e('Disable secondary menu', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="checkbox" value="true" name="antiaris_settings[disable_secondary_menu]" id="disable_secondary_menu" <?php if ($antiaris_settings['disable_secondary_menu']) {echo 'checked="checked"';} ?> />
                        </td>
                    </tr>
                </table>
                
                <h4><?php _e('Favicon options'); ?></h4>
                <table class="form-table">
                    <tr>
                        <th scope="row" style="width:250px;">
                        	<label for="favicon_url"><?php _e('Favicon URL', 'antiaris'); ?></label>
                        </th>
                        <td>
                        	<input type="text" class="widefat code" value="<?php echo $antiaris_settings['favicon_url']; ?>" name="antiaris_settings[favicon_url]" id="favicon_url" />
                            <span class="description"><?php _e('Simply enter the full URL to your favicon file here to enable favicon. Make sure you include the <code>http://</code> in front of the URL as well.', 'antiaris'); ?></span>
                        </td>
                    </tr>
                </table>
            </div>
        </div>
        
        
        <?php /* Custom CSS */ ?>
        <div class="postbox">
            <div class="head-wrap">
            	<div title="Click to toggle" class="handlediv"><br /></div>
            	<h3 class="hndle"><?php _e('Custom CSS', 'antiaris'); ?></h3>
            </div>
            <div class="panel-wrap inside">
                <table class="form-table">
                    <tr>
                        <th scope="row"><label><?php _e('Custom CSS styles', 'antiaris'); ?></label></th>
                        <td>
                        	<span class="description"><?php _e("You can enter your own CSS codes below to modify any other aspects of the theme's appearance that is not included in the options.", 'antiaris'); ?></span>
                        	<textarea name="antiaris_settings[custom_css]" cols="60" rows="20" class="widefat code"><?php echo stripslashes($antiaris_settings['custom_css']); ?></textarea>
                        </td>
                    </tr>
                </table>
            </div>
        </div>
       
        <?php /* The form submit button */ ?>
        <p class="submit"><input type="submit" class="button-primary" value="<?php _e('Save Options', 'antiaris'); ?>" /></p>
        
        <?php /* Close the main form */ ?>
        </form>
        
        </div><!--.left-wrap-->
        
        <div class="side-wrap">
        
			<?php /* Paypal donation button */ ?>
            <div class="postbox donation">
                <div>
                    <h3 class="hndle"><?php _e('Support the developer', 'antiaris'); ?></h3>
                </div>
                <div class="panel-wrap inside">
                    <p><?php _e('Developing this awesome theme took a lot of efforts and time, weeks and weeks of voluntary unpaid work. Its features rival many of those paid premium themes available out there.', 'antiaris'); ?></p>
                    <p><?php _e('In fact, I meant for this theme to be treated as a "free premium theme", which is like a premium theme that you can test-drive indefinitely, and affordable to all as you decide the price yourself, if it\'s worth your hard-earned money.', 'antiaris'); ?></p>
                    <p><?php _e('If you like this theme or if you are using it for commercial websites, please consider a donation to the developer to help support future updates and development.', 'antiaris'); ?></p>
                    <form action="https://www.paypal.com/cgi-bin/webscr" method="post">
                        <input type="hidden" name="cmd" value="_s-xclick">
                        <input type="hidden" name="hosted_button_id" value="TQRSTQP6DZ7KS">
                        <input type="image" src="https://www.paypal.com/en_US/i/btn/btn_donateCC_LG.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online!">
                        <img alt="" border="0" src="https://www.paypal.com/en_US/i/scr/pixel.gif" width="1" height="1">
                    </form>
                </div>
            </div>
            
            
            <?php /* Uninstall theme */ ?>
            <div class="postbox theme-uninstall">
                <div class="head-wrap">
                	<div title="Click to toggle" class="handlediv"><br /></div>
                    <h3 class="hndle"><?php _e('Uninstall theme', 'antiaris'); ?></h3>
                </div>
                <div class="panel-wrap inside">
                    <p><?php _e("<strong>Be careful!</strong> Uninstalling the theme will remove all of the theme's options from the database. Do this only if you decide not to use the theme anymore.",'antiaris'); ?></p>
                    <p><?php _e('If you just want to try another theme, there is no need to uninstall this theme. Simply activate the other theme in the Appearance > Themes admin page.','antiaris'); ?></p>
                    <p><?php _e("Note that uninstalling this theme <strong>does not remove</strong> the theme's files. To delete the files after you have uninstalled this theme, go to Appearances > Themes and delete the theme from there.",'antiaris'); ?></p>
                    <form action="" method="post">
                        <?php wp_nonce_field('antiaris-uninstall', 'antiaris-uninstall'); ?>
                    
                        <input type="hidden" name="antiaris_uninstall" value="true" />
                        <input type="submit" class="button antiaris_uninstall" value="<?php _e('Uninstall Theme', 'antiaris'); ?>" />
                    </form>
                </div>
            </div>
            
    	</div><!--.side-wrap-->
        
    </div>
<?php } 

/**
 * Add JavaScript to hide and show the options panel
*/
function antiaris_options_js(){ ?>
	<script type="text/javascript">
	<!--
	jQuery(document).ready(function($){
        $('.meta-box-sortables .head-wrap').click(function(){
            $(this).next().toggle(400);
            return false;
        }).next().hide();
    });
	//-->
	</script>
<?php
}
add_action('admin_footer', 'antiaris_options_js');

?>