<?php
/**
 * The template for displaying Comments.
 *
 * The area of the page that contains both current comments
 * and the comment form.  The actual display of comments is
 * handled by a callback to antiaris_comments which is
 * located in the functions.php file.
 *
 * @package WordPress
 * @subpackage Antiaris
 * @since Antiaris 1.0
 */
global $antiaris_settings;
if (post_password_required()) : ?>
    <div id="comments">
        <p class="nopassword"><?php _e( 'This post is password protected. Enter the password to view any comments.', 'antiaris' ); ?></p>
        
        <?php do_action('antiaris_protected_comment'); ?>
    </div><!-- #comments -->
<?php
	/* Stop the rest of comments.php from being processed,
	 * but don't kill the script entirely -- we still have
	 * to fully load the template.
	 */
	return;
endif;
?>

<?php /* Lists all the comments for the current post */ ?>
<?php if (have_comments()) : ?>
    <div id="comments" class="clearfix">
        
        <?php /* Comment count */ ?>
        <h3 class="comments-count">
			<?php echo antiaris_comment_count('comments', __('No comment yet','antiaris'), __('1 comment','antiaris'), __("% comments", 'antiaris'));?>
        </h3>
        <h3 class="pings-count">
			<?php echo antiaris_comment_count('pings', __('No pingbacks yet','antiaris'), __('1 pingback','antiaris'), __("% pingbacks", 'antiaris'));?>
        </h3>
        
        <?php do_action('antiaris_before_comments'); ?>
        
        <?php /* List the comment */ ?>
        <ol class="clearfix" id="comments-list">
            <?php
			/* Loop through and list the comments. Tell wp_list_comments()
			 * to use antiaris_comment() to format the comments.
			 * If you want to overload this in a child theme then you can
			 * define antiaris_comment() and that will be used instead.
			 * See antiaris_comment() in functions.php for more.
			*/ 
			$args = array(
						'type' => 'comment',
						'callback' => 'antiaris_comments',
						'style' => 'ol',
						  );
			wp_list_comments(apply_filters('antiaris_list_comments_args', $args)); ?>
        </ol>
        
        <ol class="clearfix" id="pings-list">
			<?php
            /* Loop through and list the pings. Use the same callback function as
             * listing comments above, antiaris_comments() to format the pings.
             */
             $args = array(
						'type' => 'pings',
						'callback' => 'antiaris_comments',
						'style' => 'ol',
						  );
			wp_list_comments(apply_filters('antiaris_list_pings_args', $args)); ?>
        </ol>
        
        <?php /* Comments pagination */ ?>
        <?php if (get_comment_pages_count() > 1 && get_option('page_comments')) : ?>
        <div class="comment-nav clearfix">
            <p><?php paginate_comments_links(); ?>&nbsp;</p>
            <?php do_action('antiaris_comments_pagination'); ?>
        </div>
        <?php endif; ?>
        
    <?php do_action('antiaris_after_comments'); ?>
	</div>
<?php endif; // Ends the comment listing ?>
    
    
<?php /* Display comments disabled message if there's already comments, but commenting is disabled */ ?>
<?php if (!comments_open() && have_comments()) : ?>
	<div id="respond">
		<h3 id="reply-title"><?php _e('Comments have been disabled.', 'antiaris'); ?></h3>
        <?php do_action('antiaris_comments_disabled'); ?>
    </div>
<?php endif; ?>


<?php if (comments_open()) :

	do_action('antiaris_before_commentform');

	/**
	 * Get the comment form.
	*/ 
	
	/* translators: %s will be replaced with the list of allowed HTML tags and attributes */
	if (!$antiaris_settings['hide_comments_allowed_tags']) {
		$allowedtags = '<p class="form-allowed-tags">'.sprintf(__('You may use these <abbr title="HyperText Markup Language">HTML</abbr> tags and attributes: %s', 'antiaris'),'<code>'.allowed_tags().'</code>').'</p>';
	} else {
		$allowedtags = '';	
	}
	
	$args = array(
				'comment_notes_before' => '<p class="comment-notes">'.__('Your email address will not be published.', 'antiaris').'</p>',
				'comment_notes_after'  => $allowedtags,
				'id_form'              => 'commentform',
				'label_submit'         => __('Submit Comment', 'antiaris'),
				'cancel_reply_link'    => '&raquo; '.__('Cancel reply', 'antiaris'),
			);
	comment_form(apply_filters('antiaris_comment_form_args', $args)); 
	
	do_action('antiaris_after_commentform');

endif; // Ends the comment status ?>