<?php
/**
 * The Header for our theme.
 *
 * Displays all of the <head> section and everything up till <div id="left">
 *
 * @package WordPress
 * @subpackage Antiaris
 * @since antiaris 1.0
 */
 global $antiaris_settings, $antiaris_defaults;
 
?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" <?php language_attributes(); ?>>
<head profile="http://gmpg.org/xfn/11">
    <meta http-equiv="Content-Type" content="<?php bloginfo('html_type'); ?>; charset=<?php bloginfo('charset'); ?>" />
    <title><?php antiaris_title(); ?></title>
	<link rel="pingback" href="<?php bloginfo('pingback_url'); ?>" />
    <?php
	/* We add some JavaScript to pages with the comment form
	 * to support sites with threaded comments (when in use).
	 */
	if (is_singular() && get_option('thread_comments'))
		wp_enqueue_script('comment-reply');

	/* Always have wp_head() just before the closing </head>
	 * tag of your theme, or you will break many plugins, which
	 * generally use this hook to add elements to <head> such
	 * as styles, scripts, and meta tags.
	 */
	wp_head();
	?>
</head><?php flush(); ?>
<body <?php body_class(); ?>>
	<div id="container">
    	<div id="header_container" class="box-shadow">
        
        	<?php /* The header */ ?>
            <?php /* Get the header styles */
				$header_img = get_header_image();
				if ('blank' == get_theme_mod('header_textcolor', HEADER_TEXTCOLOR) || '' == get_theme_mod('header_textcolor', HEADER_TEXTCOLOR))
					$style = ' style="display:none;"';
				else
					$style = ' style="color:#' . get_theme_mod( 'header_textcolor', HEADER_TEXTCOLOR ) . ';"';
			?>
            <div id="header" class="clearfix" style="background:url(<?php echo $header_img; ?>);">
            	
                <?php /* Header widget area */
				if ($antiaris_settings['enable_header_widget'] && is_active_sidebar('header-widget-area')) {
					dynamic_sidebar('header-widget-area');
				}
				?>
                
            
            	<?php /* Website's title and description text */ ?>                
                <?php if (is_front_page()) : ?><h1<?php else : ?><h2<?php endif; ?> class="header_title">
                	<a href="<?php echo home_url(); ?>" title="<?php esc_attr_e('Go back to the front page', 'antiaris'); ?>" <?php echo $style; ?>><?php bloginfo('name'); ?></a>
                <?php if (is_front_page()) : ?></h1><?php else : ?></h2><?php endif; ?>
            	
				<?php if (is_front_page()) : ?><h2<?php else : ?><h3<?php endif; ?> class="header_desc" <?php echo $style; ?>>
					<?php bloginfo('description'); ?>
                <?php if (is_front_page()) : ?></h2><?php else : ?></h3><?php endif; ?>
            	
				<?php do_action('antiaris_header'); ?>
                
            </div><!--#header-->
            <?php /* Navigation bar */ 
				$args = array(
						  'container' => 'none',
						  'menu_id' => 'header-menu',
						  'menu_class' => 'menu clearfix',
						  'fallback_cb' => 'antiaris_default_menu',
						  'depth' => 0, 
						  'theme_location' => 'header-menu',
						  );
				wp_nav_menu(apply_filters('antiaris_header_menu_args', $args)); 
			?>
	
			<?php do_action('antiaris_top_menu'); ?>
        </div><!--#header_container-->
            
        <div id="top" class="clearfix box-shadow">
        	<?php /* RSS and Search bar */ ?>
        	<div id="top-bar"<?php if (!is_home()) echo ' class="content"'; ?>>
            	<div id="rss">
                	<?php $feed_url = ($antiaris_settings['feed_url']) ? $antiaris_settings['feed_url'] : get_bloginfo('rss2_url'); ?>
                	<a href="<?php echo $feed_url; ?>" title="<?php _e('Click to subscribe to the RSS feed', 'antiaris'); ?>"><span><?php _e('RSS feed', 'antiaris'); ?></span></a>
                    
                    <?php do_action('antiaris_feed'); ?>
                </div>
                <?php get_search_form(); ?>
            </div>
            
            <?php /* The Site Summary panel */ ?>
            <?php do_action('antiaris_summarypanel'); ?>
        </div>
        
        <div id="main-content" class="clearfix box-shadow">
        
        	<?php /* Secondary menu */ ?>
            <?php if (!$antiaris_settings['disable_secondary_menu']) : ?>
            <div id="secondary-menu-wrap" class="clearfix">
				<?php
                    $args = array(
                              'container' => 'none',
                              'menu_id' => 'secondary-menu',
                              'menu_class' => 'menu clearfix',
                              'fallback_cb' => 'antiaris_default_secondary_menu',
                              'depth' => 0, 
                              'theme_location' => 'secondary-menu',
                              );
                    wp_nav_menu(apply_filters('antiaris_secondary_menu_args', $args)); 
                ?>
            </div>
            <?php endif; ?>
            
            <?php /* Get the left sidebar */ 
				get_template_part('sidebar', 'left'); 
			?>
            
            <div id="left">